<?php
/**
 * Registro0CNABSantander
 *
 * @package    Logic
 * @subpackage Registro/Cnab
 *
 * @author     thalesvalias - 27/07/2012
 *
 */
class Registro0CNABSantander extends RegistroCNAB{

    const NOME_BANCO_SANTANDER = 'Banco Santander';
    const LOTE_SERVICO_REGISTRO_0 = '0000';
    const REGISTRO_0 = '0';
    const VERSAO_LAYOUT = '060';
    const CODIGO_REMESSA = '1';

    private $_estrutura;
    private $_sequencia;
    private $_codConvenioBanco;

    /**
     * Gera Tipo de Registro 0 - Registro Header de Arquivo.
     *
     * @return void
     *
     * @author thalesvalias - 27/07/2012
     */
    public function geraRegistro0(){
        $this->_geraRegistro();
    }


    /**
     * Atribui os dados no atributo da classe Pai.
     *
     * @return void
     *
     * @author thalesvalias - 27/07/2012
     */
    private function _geraRegistro(){
        // Bloco 1 ao 3 eh gerado no pai.
        parent::geraRegistro(self::REGISTRO_0, CNABSantander::CODIGO_BANCO_SANTANDER, self::LOTE_SERVICO_REGISTRO_0);

        // Bloco 4 | 009-017 | Filler (Caracter branco).
        $this->atribuiDado(parent::CARACTER_BRANCO, 9, parent::CARACTER_BRANCO, parent::PREENCHE_DIREITA);

        // Bloco 5 | 018 | Tipo de Inscricao da Empresa. 1 = CPF / 2 = CNPJ.
        $this->atribuiDado($this->_estrutura->nrTpInscricao, 1);

        // Bloco 6 | 019-032 | Numero Inscricao da Empresa.
        $this->atribuiDado($this->_estrutura->nrInscricao, 14, parent::CARACTER_ZERO, parent::PREENCHE_ESQUERDA);

        // Bloco 7 | 033-052 | Codigo do Convenio no Banco.
        // Codigo adotado pelo Banco para identificar o Contrato entre este e a Empresa Cliente.
        // Deve ser fornecido pelo Banco.
        $this->atribuiDado($this->_codConvenioBanco, 20, parent::CARACTER_BRANCO, parent::PREENCHE_DIREITA);

        // Bloco 8 | 053-057 | Agencia Mantenedora da Conta.
        // Agencia Mantenedora deve ser preenchida sem DV.
        $this->atribuiDado($this->_estrutura->agencia, 5, parent::CARACTER_ZERO, parent::PREENCHE_ESQUERDA);

        // Bloco 9 | 058 | Digito Verificador da Agencia. Deve ficar em branco.
        $this->atribuiDado(parent::CARACTER_BRANCO, 1, parent::CARACTER_BRANCO, parent::PREENCHE_DIREITA);

        // Bloco 10 | 059-070 | Numero da Conta Corrente.
        // Conta Corrente deve ser informada sem DV, pois este deve ser preenchido na posicao 71.
        $this->atribuiDado(parent::retornaContaCorrenteSemDigito($this->_estrutura->contaCorrente), 12, parent::CARACTER_ZERO, parent::PREENCHE_ESQUERDA);

        // Bloco 11 | 071 | Digito Verificador da Conta.
        $this->atribuiDado(parent::retornaDigitoContaCorrente($this->_estrutura->contaCorrente), 1, parent::CARACTER_ZERO, parent::PREENCHE_ESQUERDA);

        // Bloco 12 | 072 | Digito Verificador da Agencia / Conta. Deve ficar em branco.
        $this->atribuiDado(parent::CARACTER_BRANCO, 1, parent::CARACTER_BRANCO, parent::PREENCHE_DIREITA);

        // Bloco 13 | 073-102 | Nome da Empresa (Razao Social). Obrigatorio.
        $this->atribuiDado($this->_estrutura->historico->getNmrazsocestrut(), 30, parent::CARACTER_BRANCO, parent::PREENCHE_DIREITA);

        // Bloco 14 | 103-132 | Nome do Banco.
        $this->atribuiDado(self::NOME_BANCO_SANTANDER, 30, parent::CARACTER_BRANCO, parent::PREENCHE_DIREITA);

        // Bloco 15 | 133-142 | Filler (Caracter branco).
        $this->atribuiDado(parent::CARACTER_BRANCO, 10, parent::CARACTER_BRANCO, parent::PREENCHE_DIREITA);

        // Bloco 16 | 143 | Codigo Remessa / Retorno (1=Remessa / 2=Retorno).
        $this->atribuiDado(self::CODIGO_REMESSA, 1, parent::CARACTER_ZERO, parent::PREENCHE_ESQUERDA);

        // Bloco 17 | 144-151 | Data da Geracao do Arquivo (DDMMAAAA).
        $this->_atribuiDataCorrente();

        // Bloco 18 | 152-157 | Hora da Geracao do Arquivo (HHMMSS).
        $this->_atribuiHoraCorrente();

        // Bloco 19 | 158-163 | Numero Sequencial do Arquivo.
        // Evoluir um numero sequencial a cada Header de Arquivo.
        $this->atribuiDado($this->_sequencia, 6, parent::CARACTER_ZERO, parent::PREENCHE_ESQUERDA);

        // Bloco 20 | 164-166 | Numero da Versao do Layout. 060.
        $this->atribuiDado(self::VERSAO_LAYOUT, 3, parent::CARACTER_ZERO, parent::PREENCHE_ESQUERDA);

        // Bloco 21 | 167-171 | Densidade de Gravacao Arquivo. Preencher com zero.
        $this->atribuiDado(parent::CARACTER_ZERO, 5, parent::CARACTER_ZERO, parent::PREENCHE_ESQUERDA);

        // Bloco 22 | 172-191 | Uso Reservado do Banco. Passar branco.
        $this->atribuiDado(parent::CARACTER_BRANCO, 20, parent::CARACTER_BRANCO, parent::PREENCHE_DIREITA);

        // Bloco 23 | 192-211 | Uso Reservado da Empresa. Opcional.
        $this->atribuiDado(parent::CARACTER_BRANCO, 20, parent::CARACTER_BRANCO, parent::PREENCHE_DIREITA);

        // Bloco 24 | 212-230 | Filler.
        $this->atribuiDado(parent::CARACTER_BRANCO, 19, parent::CARACTER_BRANCO, parent::PREENCHE_DIREITA);

        // Bloco 25 | 231-240 | Ocorrencias para o Retorno.
        // Codigo adotado para identificar as ocorrencias detectadas no processamento.
        // Pode-se informar ate 5 ocorrencias simultaneamente, cada uma delas codificada com dois
        // digitos, conforme relacao das paginas 32 e 33.
        $this->atribuiDado(parent::CARACTER_BRANCO, 10, parent::CARACTER_BRANCO, parent::PREENCHE_DIREITA);
    }


    public function setEstrutura($estrutura){
        $this->_estrutura = $estrutura;
    }


    public function setSequencia($sequencia){
        $this->_sequencia = $sequencia;
    }


    public function setCodConvenioBanco($codConvenioBanco){
        $this->_codConvenioBanco = $codConvenioBanco;
    }



    /**
     * Seta o dia da rescisao do vinculo.
     *
     * @return void
     *
     * @author thalesvalias 01/08/2012
     */
    private function _atribuiDataCorrente(){

        $dataAtual = new TkDateTime();
        $dtAtual = $dataAtual->toString(TkDateTime::FORMAT_DATE);

        $this->atribuiDado($dtAtual, 8);
    }


    /**
     * Seta o dia da rescisao do vinculo.
     *
     * @return void
     *
     * @author thalesvalias 01/08/2012
     */
    private function _atribuiHoraCorrente(){

        $dataAtual = new TkDateTime();
        $horaAtual = $dataAtual->toString(TkDateTime::FORMAT_TIME);

        $this->atribuiDado($horaAtual, 6);
    }



}