/******************************************************************************/
/* Sistemas Integrados TECNISA                                                */
/*                                                                            */
/* Compras e Suprimentos                                                      */
/*                                                                            */
/******************************************************************************/
/*                                                                            */
/* Nome: HISTORICO_COTACAO                                                          */
/*                                                                            */
/* Descrio:                                                                 */
/* Retorna dados para o histrico de cotaes                                                  */
/*                                                                            */
/*                                                                            */
/* Criao:                                                                   */
/* 14/04/2000 - Adriano de Arajo                                            */
/*                                                                            */
/* Manutenes:                                                               */
/*   /  /   -                                                                 */
/*                                                                            */
/*                                                                            */
/******************************************************************************/

/******************************************************************************/
/* PARAMETROS:                                                                */
/* @D:\DIR_H\SISTEMAS\DBA\SQL\ORACLE\8320_SUPSTP_HISTORICO_COTACAO.SQL        */
/* @H:\SISTEMAS\DBA\SQL\ORACLE\8320_SUPSTP_HISTORICO_COTACAO.SQL              */
/******************************************************************************/


CREATE OR REPLACE PROCEDURE HISTORICO_COTACAO
             (P_CDFILIAL     IN FILIAL.CDFILIAL%TYPE,
              P_NRCOLEPRECO  IN COLETAPR.NRCOLEPRECO%TYPE,
              P_CDPRODUTO    IN PRODUTO.CDPRODUTO%TYPE,
              P_CDMARCA      IN MARCA.CDMARCA%TYPE,
              P_CDFORNECED   IN FORNECEDOR.CDFORNECED%TYPE,
              P_CDREGIAO     IN REGIAO.CDREGIAO%TYPE,
              P_VRULTCOT_PRUN  OUT ITEMCOLE.VRPRECUNIITM%TYPE ,
              P_VRULTCOT_ECO   OUT ITEMCOLE.VRPRECECOITM%TYPE ,
              P_NMFORN_NORM    OUT FORNECEDOR.NMFANTFORN%TYPE ,
              P_VRFNORM_PRUN   OUT ITEMCOLE.VRPRECUNIITM%TYPE ,
              P_VRFNORM_ECO    OUT ITEMCOLE.VRPRECECOITM%TYPE ,
              P_NMFORN_ALTER    OUT FORNECEDOR.NMFANTFORN%TYPE,
              P_VRFALTER_PRUN   OUT ITEMCOLE.VRPRECUNIITM%TYPE,
              P_VRFALTER_ECO    OUT ITEMCOLE.VRPRECECOITM%TYPE,
              P_PERVARIACAO     OUT NUMBER ,
              P_DTINIVAL_ULTCOT OUT ITEMCOLE.DTINIVALITM%TYPE ,
              P_DTFINVAL_ULTCOT OUT ITEMCOLE.DTFINVALITM%TYPE ,
              P_DTINIVAL_MINPRFN OUT ITEMCOLE.DTINIVALITM%TYPE,
              P_DTFINVAL_MINPRFN OUT ITEMCOLE.DTFINVALITM%TYPE,
              P_DTINIVAL_MINPRFA OUT ITEMCOLE.DTINIVALITM%TYPE,
              P_DTFINVAL_MINPRFA OUT ITEMCOLE.DTFINVALITM%TYPE)
IS
 V_ATUAL_PR      NUMBER;
 V_DTINIVALITM   DATE;
 V_DTFINVALITM   DATE;

 V_VRULTCOT_PRUN  ITEMCOLE.VRPRECUNIITM%TYPE ;
 V_VRULTCOT_ECO   ITEMCOLE.VRPRECECOITM%TYPE ;
 V_NMFORN_NORM    FORNECEDOR.NMFANTFORN%TYPE ;

 V_VRFNORM_PRUN   ITEMCOLE.VRPRECUNIITM%TYPE ;
 V_VRFNORM_ECO     ITEMCOLE.VRPRECECOITM%TYPE ;
 V_NMFORN_ALTER    FORNECEDOR.NMFANTFORN%TYPE;
 V_VRFALTER_PRUN    ITEMCOLE.VRPRECUNIITM%TYPE;
 V_VRFALTER_ECO     ITEMCOLE.VRPRECECOITM%TYPE;
 V_PERVARIACAO      NUMBER ;
 V_DTINIVAL_ULTCOT  ITEMCOLE.DTINIVALITM%TYPE ;
 V_DTFINVAL_ULTCOT  ITEMCOLE.DTFINVALITM%TYPE ;
 V_DTINIVAL_MINPRFN  ITEMCOLE.DTINIVALITM%TYPE;
 V_DTFINVAL_MINPRFN  ITEMCOLE.DTFINVALITM%TYPE;
 V_DTINIVAL_MINPRFA  ITEMCOLE.DTINIVALITM%TYPE;
 V_DTFINVAL_MINPRFA  ITEMCOLE.DTFINVALITM%TYPE;


BEGIN
  P_VRULTCOT_ECO  := 0;
  P_VRULTCOT_PRUN := 0;
  P_PERVARIACAO   := 0;
  P_DTINIVAL_ULTCOT := NULL;
  P_DTFINVAL_ULTCOT := NULL;

  P_VRFNORM_PRUN := 0;
  P_VRFNORM_ECO  := 0;

  P_VRFALTER_PRUN := 0;
  P_VRFALTER_ECO  := 0;


  SELECT
     MAX(ITEMCOLE.DTINIVALITM),
     MAX(ITEMCOLE.DTFINVALITM),
     MAX(ITEMCOLE.VRPRECUNIITM) INTO
                 V_DTINIVALITM,
                 V_DTFINVALITM,
                 V_ATUAL_PR
  FROM
     ITEMCOLE
  WHERE
     ITEMCOLE.CDFILIAL    = P_CDFILIAL    AND
     ITEMCOLE.NRCOLEPRECO = P_NRCOLEPRECO AND
     ITEMCOLE.CDREGIAO    = P_CDREGIAO    AND
     ITEMCOLE.CDFORNECED  = P_CDFORNECED  AND
     ITEMCOLE.CDPRODUTO   = P_CDPRODUTO   AND
     ITEMCOLE.CDMARCA     = P_CDMARCA;

   /*  ltima Cotao do Fornecedor.*/
   SELECT
     MAX(ITEMCOLE.VRPRECUNIITM),
     MAX(ITEMCOLE.VRPRECECOITM),
     MAX(ITEMCOLE.DTINIVALITM),
     MAX(ITEMCOLE.DTFINVALITM) INTO
                    V_VRULTCOT_PRUN,
                    V_VRULTCOT_ECO,
                    V_DTINIVAL_ULTCOT,
                    V_DTFINVAL_ULTCOT
   FROM
     ITEMCOLE
   WHERE
     ITEMCOLE.CDFILIAL   = P_CDFILIAL    AND
     ITEMCOLE.CDPRODUTO  = P_CDPRODUTO   AND
     ITEMCOLE.CDFORNECED = P_CDFORNECED  AND
     ITEMCOLE.CDREGIAO   = P_CDREGIAO    AND
     ITEMCOLE.NRCOLEPRECO =
       /* Selecionando a cotacao de maior nmero, a ltima */
       (SELECT
            MAX(ITEMCOLE.NRCOLEPRECO) AS COLETA
         FROM
            ITEMCOLE
         WHERE
             ITEMCOLE.CDFILIAL    =  P_CDFILIAL    AND
             ITEMCOLE.NRCOLEPRECO <> P_NRCOLEPRECO AND
             ITEMCOLE.CDPRODUTO   =  P_CDPRODUTO   AND
             ITEMCOLE.CDREGIAO   = P_CDREGIAO      AND
             ITEMCOLE.CDFORNECED  =  P_CDFORNECED);

    IF V_VRULTCOT_PRUN IS NOT NULL THEN
       IF NOT(V_VRULTCOT_PRUN = 0) THEN
          P_VRULTCOT_PRUN := V_VRULTCOT_PRUN;
          P_PERVARIACAO := ((V_ATUAL_PR - V_VRULTCOT_PRUN)/V_VRULTCOT_PRUN)*100;
          P_VRULTCOT_ECO    := V_VRULTCOT_ECO;
          P_DTINIVAL_ULTCOT := V_DTINIVAL_ULTCOT;
          P_DTFINVAL_ULTCOT := V_DTFINVAL_ULTCOT;
       ELSE
          P_VRULTCOT_PRUN   := V_VRULTCOT_PRUN;
          P_PERVARIACAO     := (V_ATUAL_PR)*100;
          P_VRULTCOT_ECO    := V_VRULTCOT_ECO;
          P_DTINIVAL_ULTCOT := V_DTINIVAL_ULTCOT;
          P_DTFINVAL_ULTCOT := V_DTFINVAL_ULTCOT;
       END IF;
    END IF;

   /* Menor preo econmico entre os fornecedores normais */
   SELECT
     MAX(FORNECEDOR.NMFANTFORN),
     MAX(ITEMCOLE.VRPRECUNIITM),
     MAX(ITEMCOLE.VRPRECECOITM) INTO
              P_NMFORN_NORM,
              P_VRFNORM_PRUN,
              P_VRFNORM_ECO

   FROM FORNECEDOR,
        ITEMCOLE,
        PARASUPRI
   WHERE
      PARASUPRI.CDFILIAL  = P_CDFILIAL   AND

      ITEMCOLE.DTINIVALITM >= V_DTINIVALITM  AND
      ITEMCOLE.DTFINVALITM <= V_DTFINVALITM  AND

      ITEMCOLE.NRCOLEPRECO <> P_NRCOLEPRECO AND

      ITEMCOLE.CDFILIAL   = P_CDFILIAL  AND
      ITEMCOLE.CDPRODUTO  = P_CDPRODUTO AND
      ITEMCOLE.CDREGIAO   = P_CDREGIAO  AND
      ITEMCOLE.CDFORNECED = FORNECEDOR.CDFORNECED AND
      FORNECEDOR.IDTIPOFORN = 'N' AND
      NVL(ITEMCOLE.VRPRECECOITM * PARASUPRI.IDTIPOAPUR, ITEMCOLE.VRPRECUNIITM) =
          (SELECT NVL(MIN(ITEMCOLE.VRPRECECOITM * PARASUPRI.IDTIPOAPUR), MIN(ITEMCOLE.VRPRECUNIITM))
           FROM
              ITEMCOLE, FORNECEDOR, PARASUPRI
           WHERE
                PARASUPRI.CDFILIAL  = P_CDFILIAL   AND
                ITEMCOLE.CDFILIAL   = P_CDFILIAL      AND
                ITEMCOLE.CDPRODUTO  = P_CDPRODUTO     AND
                ITEMCOLE.CDREGIAO   = P_CDREGIAO      AND
                ITEMCOLE.NRCOLEPRECO <> P_NRCOLEPRECO AND
                ITEMCOLE.CDFORNECED = FORNECEDOR.CDFORNECED AND
                FORNECEDOR.IDTIPOFORN = 'N');

    IF SQL%ROWCOUNT <> 0 THEN
       P_NMFORN_NORM  := V_NMFORN_NORM;
       P_VRFNORM_PRUN := V_VRFNORM_PRUN;
       P_VRFNORM_ECO  := V_VRFNORM_ECO;
    END IF;
   /* Menor preo econmico entre os fornecedores alternativos */
   SELECT
     MAX(FORNECEDOR.NMFANTFORN),
     MAX(ITEMCOLE.VRPRECUNIITM),
     MAX(ITEMCOLE.VRPRECECOITM) INTO
           P_NMFORN_ALTER,
           P_VRFALTER_PRUN,
           P_VRFALTER_ECO
   FROM FORNECEDOR,
        ITEMCOLE,
        PARASUPRI
   WHERE
      PARASUPRI.CDFILIAL  = P_CDFILIAL   AND

      ITEMCOLE.DTINIVALITM >= V_DTINIVALITM  AND
      ITEMCOLE.DTFINVALITM <= V_DTFINVALITM  AND

      ITEMCOLE.NRCOLEPRECO <> P_NRCOLEPRECO AND

      ITEMCOLE.CDFILIAL   = P_CDFILIAL  AND
      ITEMCOLE.CDPRODUTO  = P_CDPRODUTO AND
      ITEMCOLE.CDREGIAO   = P_CDREGIAO  AND
      ITEMCOLE.CDFORNECED = FORNECEDOR.CDFORNECED AND
      FORNECEDOR.IDTIPOFORN = 'A' AND
      NVL(ITEMCOLE.VRPRECECOITM * PARASUPRI.IDTIPOAPUR, ITEMCOLE.VRPRECUNIITM) =
          (SELECT NVL(MIN(ITEMCOLE.VRPRECECOITM * PARASUPRI.IDTIPOAPUR), MIN(ITEMCOLE.VRPRECUNIITM))
           FROM
              ITEMCOLE, FORNECEDOR, PARASUPRI
           WHERE
                PARASUPRI.CDFILIAL  = P_CDFILIAL   AND
                ITEMCOLE.CDFILIAL   = P_CDFILIAL      AND
                ITEMCOLE.CDPRODUTO  = P_CDPRODUTO     AND
                ITEMCOLE.CDREGIAO   = P_CDREGIAO      AND
                ITEMCOLE.NRCOLEPRECO <> P_NRCOLEPRECO AND
                ITEMCOLE.CDFORNECED = FORNECEDOR.CDFORNECED AND
                FORNECEDOR.IDTIPOFORN = 'A');

   IF SQL%ROWCOUNT <> 0 THEN
      P_NMFORN_ALTER  := V_NMFORN_ALTER;
      P_VRFALTER_PRUN := V_VRFALTER_PRUN;
      P_VRFALTER_ECO  := V_VRFALTER_ECO;
   END IF;

   P_DTINIVAL_MINPRFN := V_DTINIVALITM;
   P_DTFINVAL_MINPRFN := V_DTFINVALITM;
   P_DTINIVAL_MINPRFA := V_DTINIVALITM;
   P_DTFINVAL_MINPRFA := V_DTFINVALITM;
END;
/
